Welcome to slang's documentation!
=================================


.. include:: ./table_of_contents.rst


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`


Release: |release|

Last change: |today|
